<!DOCTYPE TS><TS>
<context>
    <name>String::DayOfWeek</name>
    <message>
        <source>MON</source>
        <translation>DLL</translation>
    </message>
    <message>
        <source>TUE</source>
        <translation>DIM</translation>
    </message>
    <message>
        <source>WED</source>
        <translation>DMC</translation>
    </message>
    <message>
        <source>THU</source>
        <translation>DIJ</translation>
    </message>
    <message>
        <source>FRI</source>
        <translation>DIV</translation>
    </message>
    <message>
        <source>SAT</source>
        <translation>DIS</translation>
    </message>
    <message>
        <source>SUN</source>
        <translation>DIU</translation>
    </message>
</context>
<context>
    <name>String::WeatherType</name>
    <message>
        <source>Cloudy</source>
        <translation>Tapat</translation>
    </message>
    <message>
        <source>Mostly Cloudy</source>
        <translation>Força tapadot</translation>
    </message>
    <message>
        <source>Partly Cloudy</source>
        <translation>Clarianes</translation>
    </message>
    <message>
        <source>Light Rain</source>
        <translation>Ruixats</translation>
    </message>
    <message>
        <source>Showers</source>
        <translation>Xàfecs</translation>
    </message>
    <message>
        <source>Rain</source>
        <translation>Pluja</translation>
    </message>
    <message>
        <source>AM Showers</source>
        <translation>Xàfecs al matí</translation>
    </message>
    <message>
        <source>Fog</source>
        <translation>Boira</translation>
    </message>
    <message>
        <source>Few Showers</source>
        <translation>Xàfecs dispersos</translation>
    </message>
    <message>
        <source>Mostly Sunny</source>
        <translation>Força sol</translation>
    </message>
    <message>
        <source>Sunny</source>
        <translation>Sol</translation>
    </message>
    <message>
        <source>Scattered Flurries</source>
        <translation>plujes disperses</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun</source>
        <translation>Tapat al matí/Sol a la tarda</translation>
    </message>
    <message>
        <source>Isolated T-Storms</source>
        <translation>Tempestes aïllades</translation>
    </message>
    <message>
        <source>Scattered Thunderstorms</source>
        <translation>Tempestes disperses</translation>
    </message>
    <message>
        <source>PM Showers</source>
        <translation>Xàfecs de tarda</translation>
    </message>
    <message>
        <source>PM Showers/Wind</source>
        <translation>Xàfecs de tarda/Vent</translation>
    </message>
    <message>
        <source>Rain/Snow Showers</source>
        <translation>Xàfecs de pluja o neu</translation>
    </message>
    <message>
        <source>Few Snow Showers</source>
        <translation>Algunes nevades</translation>
    </message>
    <message>
        <source>Cloudy/Wind</source>
        <translation>Núvol i Vent</translation>
    </message>
    <message>
        <source>Flurries/Wind</source>
        <translation>Pluja/vent dispers</translation>
    </message>
    <message>
        <source>Mostly Cloudy/Windy</source>
        <translation>Força tapat i vent</translation>
    </message>
    <message>
        <source>Rain/Thunder</source>
        <translation>PLuja i Tempesta</translation>
    </message>
    <message>
        <source>Partly Cloudy/Windy</source>
        <translation>Clarianes i vent</translation>
    </message>
    <message>
        <source>AM Rain/Snow Showers</source>
        <translation>Pluja/neu al matí/</translation>
    </message>
    <message>
        <source>Light Rain/Wind</source>
        <translation>Ruixats i ventet</translation>
    </message>
    <message>
        <source>Showers/Wind</source>
        <translation>Plujes i vent</translation>
    </message>
    <message>
        <source>Mostly Sunny/Wind</source>
        <translation>Força sol i vent</translation>
    </message>
    <message>
        <source>Flurries</source>
        <translation>Ventades</translation>
    </message>
    <message>
        <source>Rain/Wind</source>
        <translation>Vent i pluja</translation>
    </message>
    <message>
        <source>Sct Flurries/Wind</source>
        <translation>Vent dispers</translation>
    </message>
    <message>
        <source>Sct Strong Storms</source>
        <translation>Tempestes fortes disperses</translation>
    </message>
    <message>
        <source>PM T-Storms</source>
        <translation>Temporal de tardes</translation>
    </message>
    <message>
        <source>Thunderstorms</source>
        <translation>Tempesta de trons</translation>
    </message>
    <message>
        <source>Sunny/Windy</source>
        <translation>Sol/Vent</translation>
    </message>
    <message>
        <source>AM Thunderstorms</source>
        <translation>Tempesta de trons al matí</translation>
    </message>
    <message>
        <source>AM Rain</source>
        <translation>Pluja al matí</translation>
    </message>
    <message>
        <source>Iso T-Storms/Wind</source>
        <translation>Tempestes aïllades/Vent</translation>
    </message>
    <message>
        <source>Rain/Snow</source>
        <translation>Pluja/Neu</translation>
    </message>
    <message>
        <source>Sct T-Storms/Wind</source>
        <translation>Tempestes disperses/Vent</translation>
    </message>
    <message>
        <source>AM Showers/Wind</source>
        <translation>Xàfecs de matí/Vent</translation>
    </message>
    <message>
        <source>Sct Snow Showers</source>
        <translation>Nevades lleus disperses</translation>
    </message>
    <message>
        <source>Snow to Ice/Wind</source>
        <translation>Neu a glaçada/Vent</translation>
    </message>
    <message>
        <source>Snow to Rain</source>
        <translation>Neu a pluja</translation>
    </message>
    <message>
        <source>AM Light Rain</source>
        <translation>Ruixats al matí</translation>
    </message>
    <message>
        <source>PM Light Rain</source>
        <translation>Ruixats de tarda</translation>
    </message>
    <message>
        <source>PM Rain</source>
        <translation>Pluja de tarda</translation>
    </message>
    <message>
        <source>Snow Showers</source>
        <translation>Ruixats de neu</translation>
    </message>
    <message>
        <source>Rain to Snow</source>
        <translation>Pluja a neu</translation>
    </message>
    <message>
        <source>PM Rain/Snow</source>
        <translation>Pluja/Neu a la tarda</translation>
    </message>
    <message>
        <source>Few Showers/Wind</source>
        <translation>Algun ruixat/vent</translation>
    </message>
    <message>
        <source>Snow/Wind</source>
        <translation>Neu/Vent</translation>
    </message>
    <message>
        <source>PM Rain/Snow Showers</source>
        <translation>Ruixats/neu a la tarda</translation>
    </message>
    <message>
        <source>PM Rain/Snow/Wind</source>
        <translation>Ruixats/Neu i vent de tarda</translation>
    </message>
    <message>
        <source>Rain/Snow Showers/Wind</source>
        <translation>Ruixats de Pluja/Neu/Vent</translation>
    </message>
    <message>
        <source>Rain/Snow/Wind</source>
        <translation>Pluja/Neu/Vent</translation>
    </message>
    <message>
        <source>Light Snow</source>
        <translation>Nevadeta</translation>
    </message>
    <message>
        <source>PM Snow</source>
        <translation>Neu a la tarda</translation>
    </message>
    <message>
        <source>Few Snow Showers/Wind</source>
        <translation>Alguns ruixats de neu/Vent</translation>
    </message>
    <message>
        <source>Light Snow/Wind</source>
        <translation>Lleugera neu/vent</translation>
    </message>
    <message>
        <source>Wintry Mix</source>
        <translation>Ventades</translation>
    </message>
    <message>
        <source>AM Wintry Mix</source>
        <translation>Ventades pel matí</translation>
    </message>
    <message>
        <source>Hvy Rain/Freezing Rain</source>
        <translation>Forta pluja/pedregades</translation>
    </message>
    <message>
        <source>AM Light Snow</source>
        <translation>Lleugera nevada de matí</translation>
    </message>
    <message>
        <source>Rain/Freezing Rain</source>
        <translation>Pluja/pedregades</translation>
    </message>
    <message>
        <source>T-Storms/Wind</source>
        <translation>Tempesta/Vent</translation>
    </message>
    <message>
        <source>Sprinkles</source>
        <translation>Xim Xim</translation>
    </message>
    <message>
        <source>AM Snow Showers</source>
        <translation>Ruixats de neu al matí</translation>
    </message>
    <message>
        <source>AM Clouds/PM Sun/Wind</source>
        <translation>Nuvol al matí/Tarda sol/vent</translation>
    </message>
    <message>
        <source>AM Rain/Snow/Wind</source>
        <translation>Matí pluja/neu/vent</translation>
    </message>
    <message>
        <source>Rain to Snow/Wind</source>
        <translation>Pluja a neu i vent</translation>
    </message>
    <message>
        <source>Snow to Wintry Mix</source>
        <translation>Neu a ventades</translation>
    </message>
    <message>
        <source>PM Snow Showers/Wind</source>
        <translation>Ruixats de neu de tarda/vent</translation>
    </message>
    <message>
        <source>Snow and Ice to Rain</source>
        <translation>Neu i glaçada a pluja</translation>
    </message>
    <message>
        <source>Heavy Rain</source>
        <translation>Fortes plujes</translation>
    </message>
    <message>
        <source>AM Rain/Ice</source>
        <translation>Pluja i glaçades al matí</translation>
    </message>
    <message>
        <source>AM Snow Showers/Wind</source>
        <translation>Ruixats de neu de matí/vent</translation>
    </message>
    <message>
        <source>AM Light Snow/Wind</source>
        <translation>Nevadetes de matí/vent</translation>
    </message>
    <message>
        <source>PM Light Rain/Wind</source>
        <translation>Ruixadets i vent de tarda</translation>
    </message>
    <message>
        <source>AM Light Wintry Mix</source>
        <translation>Ventadetes pel matí</translation>
    </message>
    <message>
        <source>PM Light Snow/Wind</source>
        <translation>Nevadetes/vent de tarda</translation>
    </message>
    <message>
        <source>Heavy Rain/Wind</source>
        <translation>Fortes plujes i vent</translation>
    </message>
    <message>
        <source>PM Snow Shower</source>
        <translation>Ruixats de neu de tarda</translation>
    </message>
    <message>
        <source>Snow to Rain/Wind</source>
        <translation>Neu a pluja/Vent</translation>
    </message>
    <message>
        <source>PM Light Rain/Ice</source>
        <translation>Ruixadets i glaçades de tarda</translation>
    </message>
    <message>
        <source>AM Snow</source>
        <translation>Neu al matí</translation>
    </message>
    <message>
        <source>Snow to Ice</source>
        <translation>Neu a glaçada</translation>
    </message>
    <message>
        <source>Wintry Mix/Wind</source>
        <translation>Ventades/Vent</translation>
    </message>
    <message>
        <source>PM Light Snow</source>
        <translation>Nevadeta de tarda</translation>
    </message>
    <message>
        <source>AM Drizzle</source>
        <translation>Ruixadets al matí</translation>
    </message>
    <message>
        <source>Strong Storms/Wind</source>
        <translation>Tempestes fortes/Vent</translation>
    </message>
    <message>
        <source>PM Drizzle</source>
        <translation>Ruixadets de tarda</translation>
    </message>
    <message>
        <source>Drizzle</source>
        <translation>Ruixadets</translation>
    </message>
    <message>
        <source>AM Light Rain/Wind</source>
        <translation>Ruixats/Vent al matí</translation>
    </message>
    <message>
        <source>AM Rain/Wind</source>
        <translation>Pluja/Vent pel matí</translation>
    </message>
    <message>
        <source>Wintry Mix to Snow</source>
        <translation>Ventades a neu</translation>
    </message>
    <message>
        <source>Snow Showers/Windy</source>
        <translation>Ruixats de neu/Vent</translation>
    </message>
    <message>
        <source>Light Rain Shower</source>
        <translation>Ruixadets de pluja</translation>
    </message>
    <message>
        <source>Light Rain with Thunder</source>
        <translation>Ruixats amb trons</translation>
    </message>
    <message>
        <source>Light Drizzle</source>
        <translation>Lleugers ruixadets</translation>
    </message>
    <message>
        <source>Mist</source>
        <translation>Boireta</translation>
    </message>
    <message>
        <source>Smoke</source>
        <translation>Calitxa</translation>
    </message>
    <message>
        <source>Haze</source>
        <translation>Calina</translation>
    </message>
    <message>
        <source>Light Snow Shower</source>
        <translation>Ruixadet de neu</translation>
    </message>
    <message>
        <source>Light Snow Shower/ Windy</source>
        <translation>Ruixadet de neu i vent</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Cel clar</translation>
    </message>
    <message>
        <source>A Few Clouds</source>
        <translation>Alguns núvols</translation>
    </message>
    <message>
        <source>Fair</source>
        <translation>Bé</translation>
    </message>
</context>
<context>
    <name>String::WindDirection</name>
    <message>
        <source>N</source>
        <translation></translation>
    </message>
    <message>
        <source>NNE</source>
        <translation></translation>
    </message>
    <message>
        <source>NE</source>
        <translation></translation>
    </message>
    <message>
        <source>E</source>
        <translation></translation>
    </message>
    <message>
        <source>SE</source>
        <translation></translation>
    </message>
    <message>
        <source>SSE</source>
        <translation></translation>
    </message>
    <message>
        <source>S</source>
        <translation></translation>
    </message>
    <message>
        <source>SSW</source>
        <translation>SSO</translation>
    </message>
    <message>
        <source>SW</source>
        <translation>SO</translation>
    </message>
    <message>
        <source>W</source>
        <translation>O</translation>
    </message>
    <message>
        <source>NW</source>
        <translation>NO</translation>
    </message>
    <message>
        <source>NNW</source>
        <translation>NNO</translation>
    </message>
    <message>
        <source>ENE</source>
        <translation></translation>
    </message>
    <message>
        <source>ESE</source>
        <translation>OSO</translation>
    </message>
    <message>
        <source>WSW</source>
        <translation>OSO</translation>
    </message>
    <message>
        <source>WNW</source>
        <translation>ONO</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>loading...</source>
        <translation>Carregant...</translation>
    </message>
    <message>
        <source>[ retrieving weather data ... ]</source>
        <translation>[ recuperant dades meteorològiques ... ]</translation>
    </message>
    <message>
        <source>current conditions</source>
        <translation>dades actuals</translation>
    </message>
    <message>
        <source>Humidity</source>
        <translation>Humitat</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>Pressió</translation>
    </message>
    <message>
        <source>Wind</source>
        <translation>Vent</translation>
    </message>
    <message>
        <source>Visibility</source>
        <translation>Visibilitat</translation>
    </message>
    <message>
        <source>Wind Chill</source>
        <translation>Sensació</translation>
    </message>
    <message>
        <source>UV Index</source>
        <translation>Radiació solar (UV)</translation>
    </message>
    <message>
        <source>extended forecast</source>
        <translation>propers dies</translation>
    </message>
    <message>
        <source>LO</source>
        <translation>MIN</translation>
    </message>
    <message>
        <source>HI</source>
        <translation>MAX</translation>
    </message>
    <message>
        <source>today&apos;s forecast</source>
        <translation>previsió per a avui</translation>
    </message>
    <message>
        <source>tomorrow&apos;s outlook</source>
        <translation>previsió per demà</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation>Imatge del radar</translation>
    </message>
    <message>
        <source>Map Unavailable</source>
        <translation>Mapa no disponible</translation>
    </message>
    <message>
        <source>RAIN</source>
        <translation>PLUJA</translation>
    </message>
    <message>
        <source>MIX/ICE</source>
        <translation>GELADA</translation>
    </message>
    <message>
        <source>SNOW</source>
        <translation>NEU</translation>
    </message>
    <message>
        <source>LIGHT</source>
        <translation>SUAU</translation>
    </message>
    <message>
        <source>HEAVY</source>
        <translation>FORTA</translation>
    </message>
    <message>
        <source>Enter Zip Code</source>
        <translation>Còdi Postal</translation>
    </message>
    <message>
        <source>weather setup</source>
        <translation>Configuració de &quot;El Temps&quot;</translation>
    </message>
    <message>
        <source>To save, press &apos;i&apos; - to cancel, hit escape</source>
        <translation>Per a guardar, premi &apos;i&apos; - per cancel-lar, surti</translation>
    </message>
    <message>
        <source>Forecast for</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COLD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COLDEST</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CLOUD TEMPERATURE</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Weather</name>
    <message>
        <source> is invalid)</source>
        <translation>es invàlid)</translation>
    </message>
    <message>
        <source>   No Location Set, Please read the README</source>
        <translation>No hi ha una estació definida, llegeixi el README</translation>
    </message>
    <message>
        <source>Configuring MythWeather...</source>
        <translation>Configurant MythWeather...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select unit conversion...</source>
        <translation>Utilitzi fletxa dreta per a escollir la unitat de conversió...</translation>
    </message>
    <message>
        <source>Weather Units</source>
        <translation>Unitats </translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Estació</translation>
    </message>
    <message>
        <source>Aggressiveness</source>
        <translation>Tipus de connexió</translation>
    </message>
    <message>
        <source>Configuration Saved...</source>
        <translation>Congiguració guardada...</translation>
    </message>
    <message>
        <source>Retrieving weather data...</source>
        <translation>Obtenint dades del temps...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select your location...</source>
        <translation>Esculli la estació amb la fletxa dreta...</translation>
    </message>
    <message>
        <source>Use the right arrow key to select the aggressiveness level...</source>
        <translation>Esculli el tipus de connexió amb la fletxa dreta...</translation>
    </message>
    <message>
        <source> 1  High Speed Connection</source>
        <translation>1  Connexió d&apos;alta velocitat</translation>
    </message>
    <message>
        <source> 8  Medium Speed Connection</source>
        <translation>8  Connexió de velocitat mitjana</translation>
    </message>
    <message>
        <source> 15 Low Speed Connection</source>
        <translation>15 Connexió de baixa velocitat</translation>
    </message>
    <message>
        <source>Obtaining initial weather data...</source>
        <translation>Obtenint dades inicials del temps...</translation>
    </message>
    <message>
        <source>Updating weather data...</source>
        <translation>Actualitzant informació del temps...</translation>
    </message>
    <message>
        <source>Calm</source>
        <translation>Calma</translation>
    </message>
    <message>
        <source> at </source>
        <translation> a </translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation>ilimitada</translation>
    </message>
    <message>
        <source> (minimal)</source>
        <translation>(mínima)</translation>
    </message>
    <message>
        <source> (moderate)</source>
        <translation>(moderada)</translation>
    </message>
    <message>
        <source> (high)</source>
        <translation>(alta)</translation>
    </message>
    <message>
        <source> (extreme)</source>
        <translation>(extrema)</translation>
    </message>
    <message>
        <source>Today a high of </source>
        <translation>Avui una màxima de </translation>
    </message>
    <message>
        <source> and a low of </source>
        <translation> i una mínima de </translation>
    </message>
    <message>
        <source>. Currently there is a humidity of </source>
        <translation>. Actualment hi ha una humitat de </translation>
    </message>
    <message>
        <source>% and the winds are</source>
        <translation>% i un vent </translation>
    </message>
    <message>
        <source> calm.</source>
        <translation>calmat. </translation>
    </message>
    <message>
        <source> coming in at </source>
        <translation> bufant a </translation>
    </message>
    <message>
        <source> mph from the </source>
        <translation>mph des del </translation>
    </message>
    <message>
        <source> Km/h from the </source>
        <translation> Qm/h des del  </translation>
    </message>
    <message>
        <source> Visibility will be unlimited for today.</source>
        <translation> Visibilitat il.limitada per a avui. </translation>
    </message>
    <message>
        <source> Visibility conditions are unknown.</source>
        <translation> No es coneixen les condicions de visibilitat.</translation>
    </message>
    <message>
        <source> There will be a visibility of </source>
        <translation> Hi haurà una visibilitat de  </translation>
    </message>
    <message>
        <source> miles.</source>
        <translation> milles.</translation>
    </message>
    <message>
        <source> km.</source>
        <translation> Qm.</translation>
    </message>
    <message>
        <source>SUN</source>
        <translation type="obsolete">DIU</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Diumenge</translation>
    </message>
    <message>
        <source>MON</source>
        <translation type="obsolete">DIL</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Dilluns</translation>
    </message>
    <message>
        <source>TUE</source>
        <translation type="obsolete">DIM</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dimarts</translation>
    </message>
    <message>
        <source>WED</source>
        <translation type="obsolete">DMC</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Dimecres</translation>
    </message>
    <message>
        <source>THU</source>
        <translation type="obsolete">DIJ</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Dijous</translation>
    </message>
    <message>
        <source>FRI</source>
        <translation type="obsolete">DIV</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Divendres</translation>
    </message>
    <message>
        <source>SAT</source>
        <translation type="obsolete">DIS</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Dissabte</translation>
    </message>
    <message>
        <source>Date Error</source>
        <translation>Error de data</translation>
    </message>
    <message>
        <source>Tomorrow expect a high of </source>
        <translation>Demà s&apos;espera una màxima de </translation>
    </message>
    <message>
        <source>Expected conditions: </source>
        <translation>Condicions previstes: </translation>
    </message>
    <message>
        <source>Weather data from: </source>
        <translation>Dades meteorològiques de: </translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Actualitzant...</translation>
    </message>
    <message>
        <source> (Not All Information Available)</source>
        <translation>(No tota la informació està disponible)</translation>
    </message>
    <message>
        <source>*** Invalid Area ID Entered *** Use a valid area id.</source>
        <translation type="obsolete">*** Area Invàlida *** Entri una àrea vàlida.</translation>
    </message>
    <message>
        <source>Weather Data Not Available</source>
        <translation type="obsolete">Informació meteorològica no disponible</translation>
    </message>
    <message>
        <source>!!! Timeout Limit !!! Change aggressiveness level.</source>
        <translation type="obsolete">Temps d&apos;espera excedit !!! Canvii el tipus de connexió.</translation>
    </message>
    <message>
        <source>*** Invalid Area ID or Server Error ***</source>
        <translation>*** Identificació d&apos;àrea desconegut o error del servidor ***</translation>
    </message>
    <message>
        <source>Imperial (Fahrenheit, in, etc)</source>
        <translation></translation>
    </message>
    <message>
        <source>Metric (Celsius, kPa, etc)</source>
        <translation></translation>
    </message>
    <message>
        <source> F</source>
        <translation></translation>
    </message>
    <message>
        <source> C</source>
        <translation></translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconegut</translation>
    </message>
    <message>
        <source> - PAUSED -</source>
        <translation>- PAUSAT -</translation>
    </message>
    <message>
        <source>doppler radar</source>
        <translation type="unfinished">Imatge del radar</translation>
    </message>
    <message>
        <source>satellite image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
